function filename = write(obj,format,outfname)
%WRITE Write a ts_data object to a file
% Usage:
% 	fName = ts_write(obj,format,filename)
% Inputs:
%   obj   data to write (ts_data)
%   format file format to write (e.g., 'SAC','AH','SEISAN') [default='SAC']
%   fname  name of the file to write (leave empty for default)
%           You can use ts_datetime format codes to insert date and time
%           values (see 'help ts_datetime.char()')
% Output:
%   filename  is the name of the file (or files) written to

% W Crawford 11/2009

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%% Standard beginning for ts_* functions %%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DEBUG = ts_get('debug');                                  %
VERBOSE = ts_get('verbose');                              %
if DEBUG, disp('ts_write(): Starting'); tic; end          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% CHECK INPUT VARIABLES
if ~exist('format'); format='SAC', end
callfnctn=sprintf('ts_write%s',format);
if ~exist(callfnctn), error('%s does not exist',callfnctn); end

%% EXPAND FILE/PATHNAME AND CHECK TO SEE IF THERE ARE DIRECTORIES TO CREATE
if exist('outfname')
    if ~isempty(outfname)
        startTime=obj.channel(1).starttime;
        of=outfname;
        outfname=char(startTime,outfname);  % Puts in time info if requested
        if VERBOSE,
            if ~strcmp(of,outfname)
                fprintf('Filename %s expanded to\n',of);
                fprintf('         %s\n',outfname);
            end
        end
        [pathstr,name,ext,ver]=fileparts(outfname);
        if ~isempty(pathstr),
            if DEBUG>1,
                fprintf('ts_write(): testing existence of write path: %s\n',pathstr);
            end
            paths=strread(pathstr,'%s','delimiter',filesep());
            parent='.';p=[];
            for i=1:length(paths),
                p=[p paths{i} filesep()];
                if DEBUG>1,fprintf('\tTesting %s: ',p); end
                if ~exist(p,'dir');
                   fprintf('Creating output directory: %s\n',p);
                   mkdir(parent,paths{i});
                elseif DEBUG>1,
                    fprintf('EXISTS!\n');
                end
                parent=p;
            end
        end
    else
        clear outfname
    end
end
    


%% SEND THE COMMAND
if exist('outfname');
    cmd=sprintf('filename=%s(obj,outfname);',callfnctn);
else,
    cmd=sprintf('filename=%s(obj);',callfnctn);
end
eval(cmd);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%% Standard end for ts_* functions %%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if DEBUG,                                                 %
    fprintf('ts_write(): Exiting after %.1f seconds\n',toc); %
end                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end     % End of function                                 
