function fname = writeSDS(tdata,basedir,format)
    % Write a ts_data object to SeisComp3 Data Structure
    % Usage:
    % 	fName = writeSDS(obj) puts the dat in ./SDS/
    %	fName = writeSDS(obj,basedir) specifies the base directory
    %	fName = writeSDS(obj,basedir,format) also specifies the output format
    %		 1 = 16-bit integer 
    %		 3 = 32-bit integer
    %		 4 = IEEE float32
    %		 5 = IEEE float64
    %		10 = Steim-1 compression (data will be converted to int32)
    %		11 = Steim-2 compression (default, data will be converted to int32)
    %
    % WILL NOT OVERWRITE EXISTING FILES!!!!!
    %
    % This is slow because it uses Matlab to implement Steim2 compression
    % A faster method is to use writeSAC and then use an external SACtoMSEED
    % converter, but you won't get the automatic directory structure

    % W Crawford 10/2013
    
    ts_init;	% Sets up global variables
    
    if ~exist('basedir','var'), basedir = './SDS'; end
    if ~exist('format','var'), format = 11; end     % Steim2 compression by default
    
    ts_verbose(1,'Starting, will write to SDS directory %s',basedir);
    
    nc = tdata.nChannels;
    for i=1:nc,
        chan=tdata.channel(i);
        firstDay=floor(chan.starttime.toMatlabSerial);
        ld=chan.starttime+(chan.nSamples-1)/(chan.samprate);
        lastDay=floor(ld.toMatlabSerial);
        for day=firstDay:lastDay,
            % Cut data into present day's values
            c=chan.cut(ts_datetime(day),ts_datetime(day+1),'>=','<');
            SDSfname=makeFileName(c,basedir);
            if ~exist(fileparts(SDSfname),'dir')
                [success,message]=mkdir(fileparts(SDSfname));
                if success==0,
                    error('Could not create directory %s: %s', ...
                        fileparts(SDSfname), message);
                else
                    c.writeMSEED(SDSfname,format);
                end
            elseif exist(SDSfname,'file')
                warning('%s: File exists!  Skipping...', SDSfname);
            else
                c.writeMSEED(SDSfname,format);
            end
        end
    end
end
  
function fname=makeFileName(chan,basedir)

    if ~isa(chan,'ts_data_channel')
        error('chan is not a ts_data_channel object');
    elseif ~ischar(basedir)
        error('basedir is not a string')
    end
    md=chan.metadata;
    fname=sprintf('%s/%s/%s/%s.%s/%s.%s.%s.%s.%s.%s', ...
                    chan.starttime.char('%y'), ...
                    md.network, ...
                    md.station, ...
                    md.component, ...
                    'D', ...
                    md.network, ...
                    md.station, ...
                    md.location, ...
                    md.component, ...
                    'D', ...
                    chan.starttime.char('%y.%j') ...
                 );
    fname=fullfile(basedir,fname);
end