function [tdata,dfile] = readBINARY(dfile,startAt,readLen)
% READBINARY Generic binary file read into ts_data
%    obj = readBINARY(datafile,startAt,readlen)
%    Assumes the data are multiplexed.
% Inputs [default]:
%   dfile           A ts_file object containing (at least) the file
%                   name, the sample rate, the number of channels,
%                   and a 'custom' cell array containing:
%                       {1} the sample rate (sps)
%						{2} the machine format of the data ('ieee-be' or 'ieee-le')
%						{3} the data format: 'uint24', 'uint16' or 'uint32'
%                                   (more can be added as necessary)
% startAt [0]:	if a scalar, start that many seconds into the file
%				if an ts_datetime, start at given time
% readlen[0]:	number of seconds to read (if 0, read to end of file)
% Output:
%   tdata         A ts_data object
%   dfile         A ts_file object with the file start and end times
%                 stuffed in
%
    %%%%%%%% START ALL ts_file.read* WITH THESE LINES
    ts_debug(1,'Starting\n'); 
    tic;
    if ~exist('startAt','var'), startAt=0; end
    if ~exist('readLen','var'), readLen=0; end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    samprate=dfile.custom{1};
    if ~isnumeric(samprate), error('.custom{1} is not a numeric, should be sampling rate'); end
    machineformat=dfile.custom{2};
    dataformat=dfile.custom{3};
    
    [startAddress,readsamps]=dfile.calcReadAddresses(startAt,readLen);
    
    readspersample=1;
    switch dataformat
        case 'uint16'
            bytespervalue=2;
            readas='uint16';
        case 'uint24'
            bytespervalue=3;
            readas='uint8';
            readspersample=3;
        case 'uint32'
            bytespervalue=4;
            readas='uint32';
        otherwise
            error('Unknown data format: <%s>',dataformat);
    end
    bytespersample=bytespervalue*dfile.nChannels;
    
    % Open the data file
    fid=fopen(dfile.filename,'r',machineformat);
    % Figure out how many samples are in the data file
    fseek(fid,0,'eof');
    position=ftell(fid);
    numsamps=floor(position/bytespersample)+1;
    ts_debug(1,'File is %d bytes (%d samps=%.0f seconds) long',position,numsamps,numsamps/samprate);

    % Figure out adress to read from and number of data to read
    if readsamps==0,
        readsamps=numsamps-startAddress+1;
    elseif (startAddress+readsamps)>numsamps,
        readsamps=numsamps-startAddress+1;
        warning('You requested data beyond the file end');
    end
    ts_debug(1,'Will read from sample %d to %d',startAddress+1,startAddress+numsamps);
    
    % Read data
    fseek(fid,startAddress*bytespersample,'bof');
    chdata=fread(fid,[dfile.nChannels*readspersample,readsamps],readas);
    if readspersample>1,    % Need to add together different columns to make real data
        error('Can''t yet combine multiple words');
    end
    
    % Stuff data in ts_data object (ALL DATA, ts_data that will select
    % the read channels)
    %chdata=chdata(dfile.readchans,:);
    tdata = ts_data(chdata,samprate,dfile);
    for i = 1:length(dfile.readchans),
        tdata.channel(i).starttime = dfile.timezero+startAddress/samprate;
    end    
    
return;
