function [tdata,dfile] = readMarcus(dfile,startAt,readLen)
% READMARCUS Read Marcus Fabian's ASCII tilt data into an ts_data object
% Usage: tdata = dfile.readMarcus(startAt,readLen)
% -or- [tdata,dfile] = dfile.readMarcus(startAt,readLen)
%
% Inputs:
% dfile         A ts_file object.
% startAt:        ignored
% readLen:       ignored
%
%



%%%%%%%% START ALL ts_file.read* WITH THESE LINES
ts_debug('Starting\n'); tic;
if ~exist('startAt','var'), startAt=0; end
if ~exist('readLen','var'), readLen=0; end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if ischar(dfile),
	dfile = ts_file(dfile);
end
if get(dfile,'tzoffset'),
    error('Time-zero correction (%g seconds) not implemented for %s',fns);
end
fullfname =			[get(dfile,'pathname') get(dfile,'filename')];
if VERBOSE, disp(['Reading Marcus Fabian file ' get(dfile,'filename')]); end
fid = fopen(fullfname,'r');
if fid==-1, error(['fopen() failed to open the file ' fullfname]); end
A=fscanf(fid,'%f',[9,inf])';
fclose(fid);

%A = load(fullfname,'-ascii');
%A = A(1:1000,:);
numsamps = length(A(:,1));
totalsecs=(A(end,1)-A(1,1))*86400;
starttime = ts_datetime(A(1,2),A(1,3),A(1,4),A(1,5),A(1,6),A(1,7)+A(1,8)/1000);
endtime = ts_datetime(A(end,2),A(end,3),A(end,4),A(end,5),A(end,6),A(end,7)+A(end,8)/1000);
totalsecs=endtime-starttime;
samprate=(numsamps-1)/totalsecs;

tdata = ts_data(A(:,9)',samprate);
tdata.channel(1).starttime=starttime;
