function plot(varargin)
% Plot the instrument response
%
%    plot(filtparm, ...); plots the frequency response of the instrument
%
%	... are field, value paris specrified as in ts_figureproperties/set
%		'freqs'	specify the frequencies to plot at
%		'position' specifies the position to plot at.  Does not clear the figure
%		'title' specifies the title to plot

verbose=ts_get('verbose');
debug=ts_get('debug');

if debug, disp('ts_response/plot(): Starting'); end
filtparm = varargin{1};

% read in field, value pairs
i = 2; ich = 0;
while i < length(varargin);
	ich=0;
	field = varargin{i};
	value = varargin{i+1}; i = i+2;
	if debug, fprintf('field=%s,value=%s\n',field, char(value)); end
	switch field,
		case 'freqs',
			myfreqs=value;
		case 'position',
			myposition=value;
		case 'title',
			mytitle=value;
		otherwise,
			error(['Unknown field: ' field]);
	end
end


if ~exist('myposition','var'),
	clf
	% myposition = get(gca,'Position');
    fp=ts_figureproperties();
	[myposition,info] = fp.calcplotpos(1,1,'ylabelLeftOnly');
	clf
end
if ~exist('myfreqs','var'),
	polezeros = abs([filtparm.zeros(find(abs(filtparm.zeros) > 0)) ...
					filtparm.poles(find(abs(filtparm.poles) > 0))])/(2*pi);
	minfreq = min(polezeros);
	maxfreq = max(polezeros);
	if isempty(minfreq), minfreq=0; end
	if isempty(maxfreq), maxfreq=0; end
	if minfreq>=maxfreq,
		if minfreq==0, minfreq=.1; maxfreq=10;
        else maxfreq = 10*minfreq; end
	end
	minfreq = 10^(floor(log10(minfreq/10)));
	maxfreq = 10^(ceil(log10(maxfreq*10)));
	myfreqs = 10.^(log10(minfreq):log10(maxfreq/minfreq)/100:log10(maxfreq));
end
%min(myfreqs),max(myfreqs)
thirdheight = myposition(4)/3;
%minfreq,maxfreq,myfreqs

resp = response(filtparm,myfreqs);

% Amplitude
postop = myposition;
postop(2) = myposition(2)+thirdheight;
postop(4)=2*thirdheight;
axes('position',postop);
loglog(myfreqs,abs(resp));
v = axis; minz = v(3); maxz = v(4);
axis([min(myfreqs) max(myfreqs) minz maxz]);
p = sort(abs(filtparm.poles))/(2*pi); hold on,
i=1;
while i<=length(p);
	sym='+';
	if p(i)==0,
		numsame = length(find(p==0));
    else
		numsame =length(find(abs((p-p(i))/p(i))<1e-5));
	end
	if numsame==0; numsame=1; end
	if numsame==1, str='P';
    else str = sprintf('%dP',numsame); end
	if p(i) == 0,
		xpos = min(myfreqs);
		ypos = 10^(mean([log10(maxz) log10(minz)]));
		sym  = '<';
    else xpos = p(i); ypos = interp1(myfreqs,abs(resp),p(i));
	end
	plot(xpos,ypos,sym);
	h=text(xpos,ypos,str,'HorizontalAlignment','left','VerticalAlignment','bottom');
	i = i+numsame;
end
z = sort(abs(filtparm.zeros))/(2*pi);
i=1;
while i<=length(z);
	sym='o';
	if z(i)==0,
		numsame = length(find(z==0));
    else
		numsame =length(find(abs((z-z(i))/z(i))<1e-5));
	end
	if numsame==0; numsame=1; end
	if numsame==1, str='Z';
    else str = sprintf('%dZ',numsame); end
	if z(i) == 0,
		xpos = min(myfreqs);
		ypos = 10^(mean([log10(maxz) log10(minz)]));
		sym  = '<';
    else xpos = z(i); ypos = interp1(myfreqs,abs(resp),z(i)); end
	plot(xpos,ypos,sym);
	h=text(xpos,ypos,str,'HorizontalAlignment','left','VerticalAlignment','bottom');
	i = i+numsame;
end
hold off
ylabel(sprintf('%s/%s',filtparm.outUnits,filtparm.inUnits),'Interpreter','Latex');    % Latex avoids backwards text
grid
h=gca;
set(gca,'XTickLabel','');

% Phase
posbot = myposition;
posbot(4)=.98*thirdheight;
axes('position',posbot);
semilogx(myfreqs,angle(resp)*180/pi);
axis([min(myfreqs) max(myfreqs) -180 180]);
set(gca,'YTick',-180:90:180);
ylabel('Phase','Interpreter','Latex');    % Latex avoids backwards text
xlabel('Frequency (Hz)'); grid

axes(h);	% Make Amplitude plot current

if exist('mytitle','var');
	% ADD TITLE
	ax = axes( 'Units', 'Normal', 'Position', [0.09 0.09 0.85 0.85], 'Visible', 'off' ) ; 
	set( get( ax, 'Title' ), 'Visible', 'on' ) ;
	title( mytitle ) ; end
end
