% An example of calculating seafloor compliance
% Doesn't work well with existing file because it has glitches!

% Read in 4-channel broadband OBS data (has glitches!)
tdata=ts_file('./datafiles/RR28_20121201-20121202_0.5Hz.mseed','MSEED').read();

% Set up instrument metadata (inc transfer function)
for i=1:tdata.nChannels
    chan=tdata.channel(i).metadata.component;
    fprintf('%s=channel %d\n',chan,i)
    if chan(3)=='H',
        tdata.channel(i).metadata.response=tsresp_LCPO_DPG('L21_DPG5004_2007');
        iH=i;
    elseif chan(3)=='Z'
        tdata.channel(i).metadata.response=tsresp_LCPO_T240('Z',1,2012);
        iZ=i;
    else
        tdata.channel(i).metadata.response=tsresp_LCPO_T240('H',1,2012);
        if chan(3)=='1'
            i1=i;
        elseif chan(3)=='2'
            i2=i;
        else error('%s: no channel number assigned!',chan)
        end
    end
end

% Clean tilt (horizontals) noise from vertical
cleanXF=tdata.clean_calc([i1 i2],2048,3); 
%cleanXF=tdata.clean_calc([i1 i2 iH],2048,3); % Clear pressure too

return
cleanData=tdata.clean(cleanXF);
close all


% Calculate and plot coherence before and after cleaning
spect_before=tdata.calcSpectra('wl',2048);
spect_after=cleanData.calcSpectra('wl',2048);
figure(1)
spect_before.plotcoher();
figure(2)
spect_after.plotcoher();

xf=spect_after.calcXF(iH,iZ);

figure(3);
plot(xf)

freqs=xf.freqs(xf.gooddata);
xf_data=xf.channel.data(xf.gooddata);
xf_unc=xf.channel.uncertainty(xf.gooddata);

% xfunc is in m/s^2 / Pa
% ncomp is in 1/Pa (=xfunc*k/omega^2)
wdepth=3000;
norm_fact=gravd(2*pi*freqs,wdepth)./(2*pi*freqs).^2;
ncompl=xf_data.*norm_fact;
ncompl_unc=xf_unc.*norm_fact;
ifreqs=freqs<0.03;
ncompl=ncompl(ifreqs);
ncompl_unc=ncompl_unc(ifreqs);
ncompl_freqs=freqs(ifreqs);

figure(4); clf;
semilogy(ncompl_freqs,abs(ncompl),'o');
hold on
%semilogy(compl_freqs(:)*[1 1],[compl(:)-compl_unc(:), compl(:)+compl_unc(:)])
semilogy([1;1]*ncompl_freqs(:)',abs([ncompl(:)'-ncompl_unc(:)'; ncompl(:)'+ncompl_unc(:)']))
xlabel('Frequency (Hz)')
ylabel('Compliance (1/Pa)')
