%% ts_data_channel_metadata
% Holds metadata about a single data channel.
%
%% Properties
%
% <html>
% <table border="0" width="100%" cellpadding="10">
% <tr><td></td><td> NAME </td><td>DESCRIPTION</td><td>TYPE</td></tr>
% <tr><th colspan="4" align="left"> Site/station information </th></tr>
% <tr><td></td><td> network </td><td>Network name</td><td>2-character string</td></tr>
% <tr><td></td><td> station </td><td>Station name</td><td>character string</td></tr>
% <tr><td></td><td> component </td><td>Component name</td><td>1-3 character string</td></tr>
% <tr><td></td><td> location </td><td>Usually '00'</td><td>character string</td></tr>
% <tr><td></td><td> information </td><td>Instrument model, serial #, etc</td><td>character string</td></tr>
% <tr><td></td><td> fullname </td><td>'network.station.component' <b>(READ-ONLY)</b></td><td>character string</td></tr>
% <tr><th colspan="4" align="left"> Timing </th></tr>
% <tr><td></td><td> timezero </td><td>GMT time at which station was synchronized</td><td>ts_datetime</td></tr>
% <tr><td></td><td> tzoffset </td><td>Instrument clock offset at synchronization (seconds)</td><td>numeric scalar</td></tr>
% <tr><td></td><td> clockdrift </td><td>Linear clock drift == (endTime(inst)-endTime(GPS) ) / (endTime-startTime)</td><td>numeric scalar</td></tr>
% <tr><td></td><td> timing </td><td>{timezero, tzoffset,clockdrift}</td><td>cell array</td></tr>
% <tr><th colspan="4" align="left"> Position </th></tr>
% <tr><td></td><td> lon </td><td>Decimal Degrees E</td><td>numeric scalar</td></tr>
% <tr><td></td><td> lat </td><td>Decimal Degrees N</td><td>numeric scalar</td></tr>
% <tr><td></td><td> elev </td><td>Station meters above sealevel</td><td>numeric scalar</td></tr>
% <tr><td></td><td> wdepth </td><td>Water depth at station (0 if land station, -elev if seafloor station)</td><td>numeric scalar</td></tr>
% <tr><td></td><td> coordinates </td><td>[lon,lat,elev,wdepth]</td><td>1x4 numeric array</td></tr>
% <tr><th colspan="4" align="left"> Instrument response </th></tr>
% <tr><td></td><td> response </td><td>Instrument response</td><td>ts_response</td></tr>
% </table>
% </html>
%
%% Methods:
%
% * |ts_data_channel_metadata -| Constructor
% * |GPSTime        -| Convert instrument time to GPS time
% * |instrumentTime -| Convert GPS time to instrument time
% * |update         -| Updates values to those in a reference
% * |eq             -| Returns 1 if name,location,network & component are identical
% * |neq            -| Returns 1 if name,location,network or component are not identical
%
%% Example
meta=ts_data_channel_metadata('Napoli','IT','STS-2',40.83,14.25,25,0)
%%
meta.component='BHZ';
newmeta=meta;
meta==newmeta
%%
newmeta.component='BHN';
meta==newmeta
%%
newmeta.component='ALongString';
%% See also
% <ts_response_help.html |ts_response|>, <ts_datetime_help.html |ts_datetime|>