%% ts_data
% Time series data, combines  multiple ts_data_channel objects
%
%% Properties
%    channel     - vector of data channels                   (ts_data_channel vector)
%    ch          - Alias for "channel"
%    figureprops - how to plot figures                       (ts_data_figureproperties)
%    nChannels   - READ ONLY: how many elements in "channel" (scalar)
%
%% Methods
%  Creator
%      ts_data       - Creator
%  Data modifiers:
%      demean        - apply ts_data_channel.demean() to each channel
%      detrend       - apply ts_data_channel.detrend() to each channel
%      filter        - apply ts_data_channel.filter() to each channel
%      resample      - apply ts_data_channel.resample() to each channel
%      trueAmplitude - apply ts_data_channel.trueAmplitude() to each channel
%  Information
%      isempty        - Returns 1 is there is no data
%      issynchronized - Returns 1 if all channels start at the same time,
%                       have the same sample rate and the same length
%  Transform object(s)
%      cat            - Concatenate two or more ts_data objects (end to end)
%                       All channels must be consecutive and have
%                       the same sampling rate same.  Keeps metadata from
%                       the first channel
%      cut            - cut each channel, using ts_data_channel.cut()
%      extract        - return a ts_data channel with only the requested
%                       channels
%      synchronize    - make all channels start and end at same time
%  Write data to file:
%      writeMSEED     - write to miniSEED file
%      writeSAC       - write to SAC file(s)
%      writeSEGY      - write to SEGY file
%      writeSEISAN    - write to SEISAN file
%  Redefine Matlab methods
%      plus           - Adds two ts_data objects together.  Concatenates
%                       channels if they are consecutive and have the same
%                       metadata, puts in a separate channel otherwise
%  Other
%      setstarttimes  - set the starttime of all channels to the given value
%      calcSpectra    - calculate power spectral density and coherence
%      clean_calc     - calculate transfer function to remove correlated noise
%      clean          - remove correlated noise from one or more channels
%
%% Example
sps=40; t=0:1/sps:100; d=[sin(t/5);cos(t/6)];
d=ts_data(d,sps);
d.channel(1).md.component='sin';
d.channel(2).md.component='cos';
plot(d);
d

%% See also
% <ts_data_channel_help.html |ts_data_channel|>,
% <ts_data_figureproperties_help.html |ts_data_figureproperties|>,
