%% ts_spectra
% Store and display power spectra and coherency
% 
%% Properties
%  READ AND WRITEABLE
%    figureprops     - figure properties  (ts_figureproperties)
%  READ-ONLY, SET IN CONSTRUCTOR
%     freqs          - spectra and coherency frequencies
%     spectdata      - spectra data
%     coherdata      - coherency data
%     windowsamples  - Spectral window length (samples)
%     windowtaper    - window taper used to make spectra
%     cohsigniflevel - coherency 95% significant level
%     starttime      - Start time for ffts
%     timeoffsets    - Offset of each fft from starttime (seconds)
%     sinfo          - spectra channel information
%  Dependent (READ-ONLY)
%     nChannels      - Number of spectra channels
%     nFreqs         - Number of frequencies in each spectrum
%     nWindows       - Number of windows used to calculate spectra
%     endtime        - Time of last data used
%     windowlength   - Spectral window length (in seconds)
%
%% Methods
%  ts_spectra - Constructor
%  isempty    - Returns 1 if there is no spectra data
%  plot       - Plot the spectra
%  plotcoher  - Plot the coherency
%  calcXF     - Calculate a transfer function from the spectra
%
% Examples
sps=100; 
t=0:1/sps:200;
data=[sin(5*t)+2*sin(11*t)+0.1*rand(size(t)); ...
	sin(5*t)+2*sin(19*t)+0.1*rand(size(t))];
d=ts_data(data,100);
figure(1);plot(d,0,10)
%%
s=d.calcSpectra('wl',15)
figure(2); plot(s)
%%
figure(3); plotcoher(s)
