function thefile=tsf_LCPO_L22(theInput)
% tsf_LCPO_L28 creates a ts_file instance for L-Cheapo L-22 2C instruments
%
% Usage:   tsf = tsf_LCPO_L28(theFile)
% Inputs: 
%       theFile: (string)    filename
%                  -or-
%                (ts_file)   object describing the file (including filename)
% Output:
%       tsf:     (ts_file)   object describing the file (including response)
%         

    if isa(theInput,'ts_file'),
        if theInput.nChannels~=2,
            error('You tried to force a %d-channel ts_file object to be an LCPO_L22')
        end
        thefile=theInput;
    else
        thefile=ts_file(theInput,'LCPO');
        thefile.nChannels=2;    
    end
    
    % Enter channel names ('S' is for samprate=10-80, 'E' for samprate>80
    thefile.ch_metadata(1).component='SHZ';
    thefile.ch_metadata(2).component='SDH';    % Hydrophone
    
    % Enter standard instrument response
    gain_AD=1165084;
    gain_ampli_hydro=16;
    thefile.ch_metadata(1).response=tsresp_LCPO_L22();
    thefile.ch_metadata(2).response=ts_response('PZ','Pa','counts',gain_AD*gain_ampli_hydro*6.00e-4*4.9,-6.6667,0,2*pi*100);
end

