function thefile=tsf_LCPO_L28(theInput,samprate)
% tsf_LCPO_L28 creates a ts_file instance for L-Cheapo L-28 4C instruments
% Usage: theFile=tsf_LCPO_L28(theInput,samprate)
%   theInput is the filename, or a ts_file object
%   sampRate is the assumed data sampling rate (affects component name)

    if isa(theInput,'ts_file'),
        if theInput.nChannels~=4,
            error('You tried to force a %d-channel ts_file object to be an LCPO_L28')
        end
        thefile=theInput;
    else
        thefile=ts_file(theInput,'LCPO');
        thefile.nChannels=4;    
    end

    thefile.nChannels=4;    
    % Enter channel names (first letter should be changed automatically if
    % necessary when sampling rates are specified)
    thefile.ch_metadata(1).component='SDH'; % channel 1 = Hydrophone =  DH  
    thefile.ch_metadata(2).component='SH2'; % channel 2 =     X      =  H2
    thefile.ch_metadata(3).component='SH1'; % channel 3 =     Y      =  H1
    thefile.ch_metadata(4).component='SHZ'; % channel 4 =     Z      =  HZ
    
    % Enter standard instrument response
    gain_AD=1165084;
    gain_ampli_hydro=16;
    thefile.ch_metadata(1).response=ts_response('PZ','Pa','counts',6.00e-4*4.9*gain_AD*gain_ampli_hydro,-6.6667,0,2*pi*100);
    thefile.ch_metadata(2).response=tsresp_LCPO_L28();
    thefile.ch_metadata(3).response=tsresp_LCPO_L28();
    thefile.ch_metadata(4).response=tsresp_LCPO_L28();
end

