function resp=tsresp_LCPO_T240(component,SN,year)
% Creates a ts_response instance for an LCPO logger with Trillium T240 seismometer
% Usage: resp=tsresp_LCPO_T240(component,SN,year)
%       component='H' for horizontal, 'Z' for vertical ['H'] (the Z
%                   component has a different gain starting in 2012)
%       SN = OBS serial number (1-9)
%       year = deployment year (currently only important if < 2012) [2012]
%

    if ~exist('component'), 
        ts_warning('Setting component to ''H'' by default')
        component='H';
    end
    if ~exist('SN','var')
        ts_warning('Providing BBOBS01 values (Trillium SN < 399)')
        SN=1;
    end
    if ~exist ('year','var')
        ts_warning('Setting deployment year to >=2012');
        year=2012;
    end
        
    % L-CHEAPO gains
    gain_AD=1165084;        % A/D gain (counts/V)

    if year<2012,
        gain_ampli=0.223;
    else
        
        switch component
            case 'H'
                gain_ampli=0.223;
            case 'Z'
                gain_ampli=1;
            otherwise
                error('Unknown component: ''%s''',component);
        end
    end
    
    switch SN,
        case {1,2,3,4,5,7} % SNs 1-399
            % from Trillium240_UserGuide_15672R3.pdf
            % gain_seismo=1196.5;
            % poles=[-0.01815+1i*0.01799, -0.01815-1i*0.01799 ,-173 ,-196+1i*231 ,-196-1i*231, -732+1i*1415];
            % zeros=[0 0]; 
            % from Trillium240_UserGuide_15672R7.pdf
            gain_seismo=1196.9/2;   % Divided by two because in single-ended mode
            poles=[-0.018134+1i*0.018034, -0.018134-1i*0.018034 ,-84.4 ,-180.2+1i*224.4 ,-180.2-1i*224.4, -725, -1060, -4300, -5800 -4200+1i*4600 -4200-1i*4600];
            zeros=[0 0 -72.5 -163.3 -251 -3270]; 
        case {6,8,9}       % SNs 400+
            % from Trillium240_UserGuide_15672R7.pdf
            gain_seismo=1189/2;   % Divided by two because in single-ended mode
            poles=[-0.017699+1i*0.017604, -0.017699-1i*0.017604 ,-85.3 ,-155.4+1i*210.8 ,-155.4-1i*210.8, -713, -1140, -4300, -5800 -4300+1i*4400 -4300-1i*4400];
            zeros=[0 0 -72.5 -159.3 -251 -3270]; 
        otherwise
            error('Unknown serial number ''%d''',SN);
    end
    
    % Enter standard instrument response
    inUnits='m/s';            
	outUnits='counts';
    gain_total=gain_seismo*gain_ampli*gain_AD;
    gain_angfreq=2*pi*1;
    
    resp=ts_response('PZ','m/s','counts', gain_total, poles, zeros, gain_angfreq);
    resp.inUnits='m/s^2';  % Makes spectra outputs in m/s^2
end

