function ts_debug(level,message,varargin)
%TS_DEBUG Function to set/print TiSkit debug messages
    %   Usage:
    %       ts_debug(level)          % Sets debug level
    %       ts_debug(level, message) % Prints 'message' if level <= debuglevel
    %       ts_debug()               % Return current debug level (same as ts_get('debug')
    %
    %   message can be a fprintf-like formatted string, followed by variables
    %   Valid levels are 0 (off) 1 (normal) and 2 (kitchen sink)

    st=dbstack(1);
    if length(st)>1,
        file=st(1).file;
        name=st(1).name;
    else
        file=''; name='';
    end

    currlevel=ts_get('debug');
    if ~exist('level','var'), return; end
    if ~isnumeric(level), error('First argument (level) must be numeric'); end

    if ~exist('message','var'), 
        ts_verbose(0,'TiSKit: Setting debug level to %d: was %d',level,ts_get('debug'));            
        ts_set('debug',level);
        return; 
    end
    
    if level < 1, return; end
    if level <= currlevel
        chmsg=sprintf(message,varargin{:});
        fprintf('D%d %15s:%20s(): %s\n',level,file,name,chmsg);
    end
end

