%function currlevel=ts_verbose(level,message,varargin)
function ts_verbose(level,message,varargin)
%TS_VERBOSE Function to set/print TiSkit verbose messages
    %   Usage:
    %       ts_verbose(level)  % Sets global verbose level
    %       ts_verbose(level, message)  % Print the message if level <= verboselevel
    %       ts_verbose()       % Return current ts_verbose level (same as ts_get('verbose');
    %
    %   message can be a fprintf-like formatted string, followed by argument variables.
    %
    %   Valid levels are -1 (essential), 0 (normal), 1 (verbose), 2 (blabbermouth).
    
    st=dbstack(1);
    if length(st)>1,
        file=st(1).file;
        name=st(1).name;
    else
        file=''; name='';
    end
    
    currlevel=ts_get('verbose');
    if ~exist('level','var'), return; end
    if ~isnumeric(level), 
        error('First argument (level) must be numeric'); 
    end
    
    if ~exist('message','var'), ts_set('verbose',level); return; end
    
    if level <= currlevel
        chmsg=sprintf(message,varargin{:});
        if level<=-1,    % Essential messages
            fprintf('%s\n',chmsg);
        elseif level==0,    % Normal messages
            fprintf('%s(): %s\n',name,chmsg);
        else                % Chatty messages
            fprintf('  V%d %25s(): %s\n',level,name,chmsg);
        end
    end
end

